==> jc-1.4.0.tar.gz: jasmin/sym.h <==
// public class jasmin.sym

// class file dependencies
// @dep_class b3408fef297deae4 jasmin_sym
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_jasmin_sym_H_
#define _JC_jasmin_sym_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_jasmin_sym$sub_refs	_jc_jasmin_sym$sub_refs;
typedef struct _jc_jasmin_sym$sub_nonrefs	_jc_jasmin_sym$sub_nonrefs;
typedef struct _jc_jasmin_sym$refs	_jc_jasmin_sym$refs;
typedef struct _jc_jasmin_sym$nonrefs	_jc_jasmin_sym$nonrefs;
typedef struct _jc_jasmin_sym$object	_jc_jasmin_sym$object;

typedef struct _jc_jasmin_sym$fields_struct	_jc_jasmin_sym$fields_struct;
typedef const struct _jc_jasmin_sym$vmethods	_jc_jasmin_sym$vmethods;
typedef const struct _jc_jasmin_sym$vtable	_jc_jasmin_sym$vtable;
typedef const struct _jc_jasmin_sym$vtype	_jc_jasmin_sym$vtype;

// Class fields structure
struct _jc_jasmin_sym$fields_struct {
	jint	ABSTRACT;
	jint	COLON;
	jint	DCATCH;
	jint	DCLASS;
	jint	DCLASS__5fATTR;
	jint	DCODE__5fATTR;
	jint	DEFAULT;
	jint	DEND;
	jint	DFIELD;
	jint	DFIELD__5fATTR;
	jint	DIMPLEMENTS;
	jint	DINTERFACE;
	jint	DLIMIT;
	jint	DLINE;
	jint	DMETHOD;
	jint	DMETHOD__5fATTR;
	jint	DSET;
	jint	DSOURCE;
	jint	DSUPER;
	jint	DTHROWS;
	jint	DVAR;
	jint	EOF;
	jint	EQ;
	jint	FINAL;
	jint	FROM;
	jint	INTERFACE;
	jint	IS;
	jint	Insn;
	jint	Int;
	jint	LOOKUPSWITCH;
	jint	METHOD;
	jint	NATIVE;
	jint	Num;
	jint	PRIVATE;
	jint	PROTECTED;
	jint	PUBLIC;
	jint	SEP;
	jint	STATIC;
	jint	SYNCHRONIZED;
	jint	Str;
	jint	TABLESWITCH;
	jint	TO;
	jint	TRANSIENT;
	jint	USING;
	jint	VOLATILE;
	jint	Word;
	jint	error;
};
extern _jc_jasmin_sym$fields_struct _jc_jasmin_sym$class_fields;

// Constructors
extern void _jc_jasmin_sym$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_jasmin_sym$object *);

// Virtual methods structure
struct _jc_jasmin_sym$vmethods {
};

// Vtable
struct _jc_jasmin_sym$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_jasmin_sym$vmethods	jasmin_sym;
};

// Vtype
struct _jc_jasmin_sym$vtype {
	_jc_type			type;
	_jc_jasmin_sym$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_jasmin_sym$sub_refs {
};

// Reference instance fields (object)
struct _jc_jasmin_sym$refs {
    _jc_jasmin_sym$sub_refs	jasmin_sym;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_jasmin_sym$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_jasmin_sym$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_jasmin_sym$sub_nonrefs	jasmin_sym;
};

// Object instance structure
struct _jc_jasmin_sym$object {
	_jc_jasmin_sym$refs	refs[0];
	_jc_word		lockword;
	_jc_jasmin_sym$vtype	*vtype;
	_jc_jasmin_sym$nonrefs	nonrefs;
};

// Type structure
extern _jc_jasmin_sym$vtype _jc_jasmin_sym$type;

// Array types class info structures
_JC_DECL_ARRAYS(jasmin_sym, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_jasmin_sym$class_object;

#endif	/* _JC_jasmin_sym_H_ */

==> jc-1.4.6.tar.gz: jasmin/sym.h <==
// public class jasmin.sym

// class file dependencies
// @dep_class b3408fef297deae4 jasmin_sym
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_jasmin_sym_H_
#define _JC_jasmin_sym_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_jasmin_sym$sub_refs	_jc_jasmin_sym$sub_refs;
typedef struct _jc_jasmin_sym$sub_nonrefs	_jc_jasmin_sym$sub_nonrefs;
typedef struct _jc_jasmin_sym$refs	_jc_jasmin_sym$refs;
typedef struct _jc_jasmin_sym$nonrefs	_jc_jasmin_sym$nonrefs;
typedef struct _jc_jasmin_sym$object	_jc_jasmin_sym$object;

typedef struct _jc_jasmin_sym$fields_struct	_jc_jasmin_sym$fields_struct;
typedef const struct _jc_jasmin_sym$vmethods	_jc_jasmin_sym$vmethods;
typedef const struct _jc_jasmin_sym$vtable	_jc_jasmin_sym$vtable;
typedef const struct _jc_jasmin_sym$vtype	_jc_jasmin_sym$vtype;

// Class fields structure
struct _jc_jasmin_sym$fields_struct {
	jint	ABSTRACT;
	jint	COLON;
	jint	DCATCH;
	jint	DCLASS;
	jint	DCLASS__5fATTR;
	jint	DCODE__5fATTR;
	jint	DEFAULT;
	jint	DEND;
	jint	DFIELD;
	jint	DFIELD__5fATTR;
	jint	DIMPLEMENTS;
	jint	DINTERFACE;
	jint	DLIMIT;
	jint	DLINE;
	jint	DMETHOD;
	jint	DMETHOD__5fATTR;
	jint	DSET;
	jint	DSOURCE;
	jint	DSUPER;
	jint	DTHROWS;
	jint	DVAR;
	jint	EOF;
	jint	EQ;
	jint	FINAL;
	jint	FROM;
	jint	INTERFACE;
	jint	IS;
	jint	Insn;
	jint	Int;
	jint	LOOKUPSWITCH;
	jint	METHOD;
	jint	NATIVE;
	jint	Num;
	jint	PRIVATE;
	jint	PROTECTED;
	jint	PUBLIC;
	jint	SEP;
	jint	STATIC;
	jint	SYNCHRONIZED;
	jint	Str;
	jint	TABLESWITCH;
	jint	TO;
	jint	TRANSIENT;
	jint	USING;
	jint	VOLATILE;
	jint	Word;
	jint	error;
};
extern _jc_jasmin_sym$fields_struct _jc_jasmin_sym$class_fields;

// Constructors
extern void _jc_jasmin_sym$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_jasmin_sym$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_jasmin_sym$vmethods {
};

// Vtable
struct _jc_jasmin_sym$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_jasmin_sym$vmethods	jasmin_sym;
};

// Vtype
struct _jc_jasmin_sym$vtype {
	_jc_type			type;
	_jc_jasmin_sym$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_jasmin_sym$sub_refs {
};

// Reference instance fields (object)
struct _jc_jasmin_sym$refs {
    _jc_jasmin_sym$sub_refs	jasmin_sym;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_jasmin_sym$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_jasmin_sym$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_jasmin_sym$sub_nonrefs	jasmin_sym;
};

// Object instance structure
struct _jc_jasmin_sym$object {
	_jc_jasmin_sym$refs	refs[0];
	_jc_word		lockword;
	_jc_jasmin_sym$vtype	*vtype;
	_jc_jasmin_sym$nonrefs	nonrefs;
};

// Type structure
extern _jc_jasmin_sym$vtype _jc_jasmin_sym$type;

// Array types class info structures
_JC_DECL_ARRAYS(jasmin_sym, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_jasmin_sym$class_object;

#endif	/* _JC_jasmin_sym_H_ */
